Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Deploy ¶
func Deploy( ctx context.Context, network netconf.ID, backend *ethbackend.Backend, gasPumps []bindings.OmniGasStationGasPump, ) (common.Address, *ethclient.Receipt, error)
Deploy deploys a new L1Bridge contract and returns the address and receipt.
func DeployIfNeeded ¶
func DeployIfNeeded( ctx context.Context, network netconf.ID, backend *ethbackend.Backend, gasPumps []bindings.OmniGasStationGasPump, ) (common.Address, *ethclient.Receipt, error)
DeployIfNeeded deploys a new token contract if it is not already deployed. If the contract is already deployed, the receipt is nil.
Types ¶
type DeploymentConfig ¶
type DeploymentConfig struct {
Create3Factory common.Address
Create3Salt string
ProxyAdminOwner common.Address
Owner common.Address
Deployer common.Address
Portal common.Address
ExpectedAddr common.Address
}
func (DeploymentConfig) Validate ¶
func (cfg DeploymentConfig) Validate() error
Click to show internal directories.
Click to hide internal directories.