targets

package
v0.18.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 26, 2025 License: GPL-3.0 Imports: 15 Imported by: 0

Documentation

Overview

Package targets defines list of targets supported by Omni's v1 solver. Targets are restricted to reduce attack surface area, and keep order flow predictable. Targets restriction will be removed / lessened in future versions.

Index

Constants

const NameCygnus = "Cygnus"
const NameEigen = "Eigen"
const NameGearbox = "Gearbox"
const NameMorpho = "Morpho"
const NameOmniStaking = "OmniStaking"

Variables

var (
	// Eigen testnet.
	EigenHoleskyStrategyManager = addr("0xdfB5f6CE42aAA7830E94ECFCcAd411beF4d4D5b6")

	// Eigen mainnet.
	EigenMainnetStrategyManager = addr("0x858646372CC42E1A627fcE94aa7A7033e7CF075A")
)
var (
	// Symbiotic testnet (mainnet vaults fetched from api).
	SymbioticSepoliaWSTETHVault1 = addr("0x77F170Dcd0439c0057055a6D7e5A1Eb9c48cCD2a")
	SymbioticSepoliaWSTETHVault2 = addr("0x1BAe55e4774372F6181DaAaB4Ca197A8D9CC06Dd")
	SymbioticSepoliaWSTETHVault3 = addr("0x6415D3B5fc615D4a00C71f4044dEc24C141EBFf8")
	SymbioticHoleskyWSTETHVault1 = addr("0xd88dDf98fE4d161a66FB836bee4Ca469eb0E4a75")
	SymbioticHoleskyWSTETHVault2 = addr("0xa4c81649c79f8378a4409178E758B839F1d57a54")
)
var (
	BaseCygnusGlobalUSD = addr("0xCa72827a3D211CfD8F6b00Ac98824872b72CAb49")
)
var (
	MorphoMainnetSteakhouseVault = addr("0xbeeF010f9cb27031ad51e3333f9aF9C6B1228183")
)

Functions

func IsRestricted

func IsRestricted(network netconf.ID) bool

IsRestricted returns true if the given network restricts targets.

func RefreshForever

func RefreshForever(ctx context.Context, network netconf.ID)

RefreshForever refreshes dynamic targets forever. It blocks forever, only returning when the context is closed,

Note that technically refreshing is only required on mainnet, but testing it on all networks is useful.

Types

type Target

type Target struct {
	Name      string
	Addresses func(chainID uint64) map[common.Address]bool
}

func Get

func Get(chainID uint64, target common.Address) (Target, bool)

Get returns the allowed target for the given chain and address.

Jump to